summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp128
1 files changed, 64 insertions, 64 deletions
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
index 9e2fc061..2d13db79 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
@@ -35,9 +35,9 @@ using namespace XMPP;
static TQString lineEncode(TQString str)
{
- str.replace(TQRegExp("\\\\"), "\\\\"); // backslash to double-backslash
- str.replace(TQRegExp("\\|"), "\\p"); // pipe to \p
- str.replace(TQRegExp("\n"), "\\n"); // newline to \n
+ str.tqreplace(TQRegExp("\\\\"), "\\\\"); // backslash to double-backslash
+ str.tqreplace(TQRegExp("\\|"), "\\p"); // pipe to \p
+ str.tqreplace(TQRegExp("\n"), "\\n"); // newline to \n
return str;
}
@@ -103,8 +103,8 @@ public:
int type;
};
-JT_Register::JT_Register(Task *parent)
-:Task(parent)
+JT_Register::JT_Register(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
d->type = -1;
@@ -246,8 +246,8 @@ public:
JT_Register *jt_reg;
};
-JT_UnRegister::JT_UnRegister(Task *parent)
-: Task(parent)
+JT_UnRegister::JT_UnRegister(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
d->jt_reg = 0;
@@ -306,8 +306,8 @@ public:
TQValueList<TQDomElement> itemList;
};
-JT_Roster::JT_Roster(Task *parent)
-:Task(parent)
+JT_Roster::JT_Roster(Task *tqparent)
+:Task(tqparent)
{
type = -1;
d = new Private;
@@ -448,8 +448,8 @@ bool JT_Roster::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_PushRoster
//----------------------------------------------------------------------------
-JT_PushRoster::JT_PushRoster(Task *parent)
-:Task(parent)
+JT_PushRoster::JT_PushRoster(Task *tqparent)
+:Task(tqparent)
{
}
@@ -475,8 +475,8 @@ bool JT_PushRoster::take(const TQDomElement &e)
//----------------------------------------------------------------------------
// JT_Presence
//----------------------------------------------------------------------------
-JT_Presence::JT_Presence(Task *parent)
-:Task(parent)
+JT_Presence::JT_Presence(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -485,7 +485,7 @@ JT_Presence::~JT_Presence()
{
}
-void JT_Presence::pres(const Status &s)
+void JT_Presence::pres(const tqStatus &s)
{
type = 0;
@@ -504,7 +504,7 @@ void JT_Presence::pres(const Status &s)
if(!s.status().isEmpty())
tag.appendChild(textTag(doc(), "status", s.status()));
- tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+ tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
if(!s.keyID().isEmpty()) {
TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -529,7 +529,7 @@ void JT_Presence::pres(const Status &s)
}
}
-void JT_Presence::pres(const Jid &to, const Status &s)
+void JT_Presence::pres(const Jid &to, const tqStatus &s)
{
pres(s);
tag.setAttribute("to", to.full());
@@ -554,8 +554,8 @@ void JT_Presence::onGo()
//----------------------------------------------------------------------------
// JT_PushPresence
//----------------------------------------------------------------------------
-JT_PushPresence::JT_PushPresence(Task *parent)
-:Task(parent)
+JT_PushPresence::JT_PushPresence(Task *tqparent)
+:Task(tqparent)
{
}
@@ -569,7 +569,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
return false;
Jid j(e.attribute("from"));
- Status p;
+ tqStatus p;
if(e.hasAttribute("type")) {
TQString type = e.attribute("type");
@@ -593,7 +593,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
tag = findSubTag(e, "status", &found);
if(found)
- p.setStatus(tagContent(tag));
+ p.settqStatus(tagContent(tag));
tag = findSubTag(e, "show", &found);
if(found)
p.setShow(tagContent(tag));
@@ -653,10 +653,10 @@ bool JT_PushPresence::take(const TQDomElement &e)
//----------------------------------------------------------------------------
static TQDomElement oldStyleNS(const TQDomElement &e)
{
- // find closest parent with a namespace
- TQDomNode par = e.parentNode();
+ // find closest tqparent with a namespace
+ TQDomNode par = e.tqparentNode();
while(!par.isNull() && par.namespaceURI().isNull())
- par = par.parentNode();
+ par = par.tqparentNode();
bool noShowNS = false;
if(!par.isNull() && par.namespaceURI() == e.namespaceURI())
noShowNS = true;
@@ -676,7 +676,7 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
if(!noShowNS)
i.setAttribute("xmlns", e.namespaceURI());
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -688,8 +688,8 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
return i;
}
-JT_Message::JT_Message(Task *parent, const Message &msg)
-:Task(parent)
+JT_Message::JT_Message(Task *tqparent, const Message &msg)
+:Task(tqparent)
{
m = msg;
m.setId(id());
@@ -724,7 +724,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
// find closest xmlns
TQDomNode n = e;
while(!n.isNull() && !n.toElement().hasAttribute("xmlns"))
- n = n.parentNode();
+ n = n.tqparentNode();
TQString ns;
if(n.isNull() || !n.toElement().hasAttribute("xmlns"))
ns = "jabber:client";
@@ -742,7 +742,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
i.setAttributeNodeNS(al.item(x).cloneNode().toAttr());
}
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -756,8 +756,8 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
return i;
}
-JT_PushMessage::JT_PushMessage(Task *parent)
-:Task(parent)
+JT_PushMessage::JT_PushMessage(Task *tqparent)
+:Task(tqparent)
{
}
@@ -799,8 +799,8 @@ public:
TQString message;
};
-JT_GetLastActivity::JT_GetLastActivity(Task *parent)
-:Task(parent)
+JT_GetLastActivity::JT_GetLastActivity(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
}
@@ -858,8 +858,8 @@ bool JT_GetLastActivity::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_GetServices
//----------------------------------------------------------------------------
-JT_GetServices::JT_GetServices(Task *parent)
-:Task(parent)
+JT_GetServices::JT_GetServices(Task *tqparent)
+:Task(tqparent)
{
}
@@ -955,8 +955,8 @@ public:
VCard vcard;
};
-JT_VCard::JT_VCard(Task *parent)
-:Task(parent)
+JT_VCard::JT_VCard(Task *tqparent)
+:Task(tqparent)
{
type = -1;
d = new Private;
@@ -1055,8 +1055,8 @@ public:
TQValueList<SearchResult> resultList;
};
-JT_Search::JT_Search(Task *parent)
-:Task(parent)
+JT_Search::JT_Search(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
type = -1;
@@ -1187,8 +1187,8 @@ bool JT_Search::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_ClientVersion
//----------------------------------------------------------------------------
-JT_ClientVersion::JT_ClientVersion(Task *parent)
-:Task(parent)
+JT_ClientVersion::JT_ClientVersion(Task *tqparent)
+:Task(tqparent)
{
}
@@ -1258,8 +1258,8 @@ const TQString & JT_ClientVersion::os() const
//----------------------------------------------------------------------------
// JT_ClientTime
//----------------------------------------------------------------------------
-/*JT_ClientTime::JT_ClientTime(Task *parent, const Jid &_j)
-:Task(parent)
+/*JT_ClientTime::JT_ClientTime(Task *tqparent, const Jid &_j)
+:Task(tqparent)
{
j = _j;
iq = createIQ("get", j.full(), id());
@@ -1307,8 +1307,8 @@ bool JT_ClientTime::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_ServInfo
//----------------------------------------------------------------------------
-JT_ServInfo::JT_ServInfo(Task *parent)
-:Task(parent)
+JT_ServInfo::JT_ServInfo(Task *tqparent)
+:Task(tqparent)
{
}
@@ -1338,12 +1338,12 @@ bool JT_ServInfo::take(const TQDomElement &e)
// TQDomElement query = doc()->createElement("query");
// query.setAttribute("xmlns", "jabber:iq:time");
// iq.appendChild(query);
- // TQDateTime local = TQDateTime::currentDateTime();
+ // TQDateTime local = TQDateTime::tqcurrentDateTime();
// TQDateTime utc = local.addSecs(-getTZOffset() * 3600);
// TQString str = getTZString();
// query.appendChild(textTag("utc", TS2stamp(utc)));
// query.appendChild(textTag("tz", str));
- // query.appendChild(textTag("display", TQString("%1 %2").arg(local.toString()).arg(str)));
+ // query.appendChild(textTag("display", TQString("%1 %2").tqarg(local.toString()).tqarg(str)));
// send(iq);
// return TRUE;
//}
@@ -1417,7 +1417,7 @@ bool JT_ServInfo::take(const TQDomElement &e)
}
else if (node.startsWith(client()->capsNode() + "#")) {
TQString ext = node.right(node.length()-client()->capsNode().length()-1);
- if (client()->extensions().contains(ext)) {
+ if (client()->extensions().tqcontains(ext)) {
const TQStringList& l = client()->extension(ext).list();
for ( TQStringList::ConstIterator it = l.begin(); it != l.end(); ++it ) {
feature = doc()->createElement("feature");
@@ -1444,8 +1444,8 @@ bool JT_ServInfo::take(const TQDomElement &e)
//----------------------------------------------------------------------------
// JT_Gateway
//----------------------------------------------------------------------------
-JT_Gateway::JT_Gateway(Task *parent)
-:Task(parent)
+JT_Gateway::JT_Gateway(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -1539,8 +1539,8 @@ public:
AgentItem root;
};
-JT_Browse::JT_Browse (Task *parent)
-:Task (parent)
+JT_Browse::JT_Browse (Task *tqparent)
+:Task (tqparent)
{
d = new Private;
}
@@ -1664,8 +1664,8 @@ public:
DiscoList items;
};
-JT_DiscoItems::JT_DiscoItems(Task *parent)
-: Task(parent)
+JT_DiscoItems::JT_DiscoItems(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1753,8 +1753,8 @@ public:
DiscoItem item;
};
-JT_DiscoInfo::JT_DiscoInfo(Task *parent)
-: Task(parent)
+JT_DiscoInfo::JT_DiscoInfo(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1895,8 +1895,8 @@ public:
DiscoList list;
};
-JT_DiscoPublish::JT_DiscoPublish(Task *parent)
-: Task(parent)
+JT_DiscoPublish::JT_DiscoPublish(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1959,8 +1959,8 @@ bool JT_DiscoPublish::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_MucPresence
//----------------------------------------------------------------------------
-JT_MucPresence::JT_MucPresence(Task *parent)
-:Task(parent)
+JT_MucPresence::JT_MucPresence(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -1969,7 +1969,7 @@ JT_MucPresence::~JT_MucPresence()
{
}
-void JT_MucPresence::pres(const Status &s)
+void JT_MucPresence::pres(const tqStatus &s)
{
type = 0;
@@ -1988,7 +1988,7 @@ void JT_MucPresence::pres(const Status &s)
if(!s.status().isEmpty())
tag.appendChild(textTag(doc(), "status", s.status()));
- tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+ tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
if(!s.keyID().isEmpty()) {
TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -2013,7 +2013,7 @@ void JT_MucPresence::pres(const Status &s)
}
}
-void JT_MucPresence::pres(const Jid &to, const Status &s, const TQString &password)
+void JT_MucPresence::pres(const Jid &to, const tqStatus &s, const TQString &password)
{
pres(s);
tag.setAttribute("to", to.full());
@@ -2043,8 +2043,8 @@ class JT_PrivateStorage::Private
int type;
};
-JT_PrivateStorage::JT_PrivateStorage(Task *parent)
- :Task(parent)
+JT_PrivateStorage::JT_PrivateStorage(Task *tqparent)
+ :Task(tqparent)
{
d = new Private;
}